package com.zbf.system.service;

import java.util.List;
import com.zbf.system.domain.TAgv;

/**
 * agv列表Service接口
 *
 * @author tony
 * @date 2024-06-17
 */
public interface ITAgvService
{
    /**
     * 查询agv列表
     *
     * @param id agv列表主键
     * @return agv列表
     */
    public TAgv selectTAgvById(Long id);

    /**
     * 查询agv列表列表
     *
     * @param tAgv agv列表
     * @return agv列表集合
     */
    public List<TAgv> selectTAgvList(TAgv tAgv);

    /**
     * 新增agv列表
     *
     * @param tAgv agv列表
     * @return 结果
     */
    public int insertTAgv(TAgv tAgv);

    /**
     * 修改agv列表
     *
     * @param tAgv agv列表
     * @return 结果
     */
    public int updateTAgv(TAgv tAgv);

    /**
     * 批量删除agv列表
     *
     * @param ids 需要删除的agv列表主键集合
     * @return 结果
     */
    public int deleteTAgvByIds(Long[] ids);

    /**
     * 删除agv列表信息
     *
     * @param id agv列表主键
     * @return 结果
     */
    public int deleteTAgvById(Long id);

    /**
     * 批量禁用agv列表
     *
     * @param ids 需要禁用的agv列表主键集合
     * @return 结果
     */
    public int disabledTAgvByIds(Long[] ids);

    /**
     * 批量启用agv列表
     *
     * @param ids 需要启用的agv列表主键集合
     * @return 结果
     */
    public int enableTAgvByIds(Long[] ids);

    /**
     * 改变状态
     *
     * @param tAgv
     * @return 结果
     */
    public int updateStatus(TAgv tAgv);
}

